Styled Document

### Haptic Harness Toolkit Generator

A software to easily generate parameterized tiles for haptic harnesses

#### Description

- This software allows researchers to create an easy haptic harness by generating a tile solution
- Researchers can change harness parameters to meet their needs

#### Software Operation

1. Change parameters in the "Generate Tiles" tab
2. Click "Generate Parts" to generate the .dxf and .stl files. All parameters undergo data validation, which can be turned off using the checkbox at the bottom of the parameters pane.
3. Generated files can be found in the "exports" directory

#### Hardware Operation

##### Materials

- Tyvek: will be cut for the tiles
- EVA foam: will be cut for the liner
- Hardboard (or comparable material): will be cut for the magnet ring
- Hard 3D printable material (ex. PLA): will be print for peripheral items

##### Tile Assembly

- After files are generated, they will be exported as:
  - .dxf files to be cut on a laser cutter (.dxf files can be converetd online or in software like Adobe Illustrator)
  - .stl files to be 3D-printed
- A tile is constructed by supergluing the cut parts as shown below:

#### Dependencies:

- Pyvista
- vtkbool
- ezdxf
- Numpy
- PyQT5
- pyvistaqt